@@ -539,15 +539,8 @@ def dbus_path(p):
 
 def _get_click_dir_variable():
     '''Format click databases as variable'''
-    # snappy hardcodes the click databases and if we can detect if a snappy
-    # system then we can hardcode them too and not require click.
-    # /usr/share/doc/ubuntu-snappy is shipped by ubuntu-snappy which is only
-    # available on snappy systems. This is fairly brittle but click-apparmor
-    # functionality is moving into snappy itself, so this is ok for now
-    if os.path.exists("/usr/bin/snappy") and \
-            os.path.isdir("/usr/share/doc/ubuntu-snappy"):
-        return "{%s}" % ",".join(["/apps", "/oem", "/frameworks"])
-
+    import gi
+    gi.require_version('Click', '0.4')
     from gi.repository import Click
 
     global click_databases
@@ -632,18 +625,10 @@ def _ubuntu_transform(click_manifest, policy_version):
         newp.policyversion = policy_version
         if 'policy_version' in profile and \
            float(profile['policy_version']) != policy_version:
-            if policy_version == 15.04 and \
-               'policy_vendor' in profile and \
-               profile['policy_vendor'] == "ubuntu-snappy" and \
-               float(profile['policy_version']) == 1.3:
-                # compatibility: allow ubuntu-snappy/1.3 on 15.04 transform
-                # until apps migrate
-                newp.policyversion = float(profile['policy_version'])
-            else:
-                raise AppArmorExceptionClickInvalidPolicyVersion(
-                    "Invalid policy version '%s' " %
-                    profile['policy_version'] +
-                    "for framework '%s'" % click_manifest.framework)
+            raise AppArmorExceptionClickInvalidPolicyVersion(
+                "Invalid policy version '%s' " %
+                profile['policy_version'] +
+                "for framework '%s'" % click_manifest.framework)
 
         newp.add_variable("APP_PKGNAME", click_manifest.app_pkgname)
         newp.add_variable("APP_APPNAME", click_manifest.app_appname)
@@ -709,11 +694,6 @@ def transform(click_manifest):
 def to_profiles(easyprof_manifest, directory, include=[], no_verify=False):
     '''Convert manifest to AppArmor profile'''
     args = []
-    args.append('--include-templates-dir=%s' %
-                os.path.join(framework_includes_dir, "templates"))
-    args.append('--include-policy-groups-dir=%s' %
-                os.path.join(framework_includes_dir, "policygroups"))
-
     (easy_opts, easy_args) = apparmor.easyprof.parse_args(args=args)
 
     profiles = apparmor.easyprof.parse_manifest(json.dumps(easyprof_manifest),
@@ -859,16 +839,9 @@ framework_transforms = {
     "ubuntu-sdk-14.10": (_ubuntu_transform, 1.2),
     "ubuntu-sdk-15.04": (_ubuntu_transform, 1.3),
     "ubuntu-sdk-15.10": (_ubuntu_transform, 15.10),
-    "ubuntu-core-15.04": (_ubuntu_transform, 15.04),
-    "ubuntu-core-15.10": (_ubuntu_transform, 15.10),
-    "ubuntu-core-16.04": (_ubuntu_transform, 16.04),
-    "ubuntu-personal-15.10": (_ubuntu_transform, 15.10),
-    "ubuntu-personal-16.04": (_ubuntu_transform, 16.04),
+    "ubuntu-sdk-16.04": (_ubuntu_transform, 16.04),
 }
 
-# Define where framework policy files live
-framework_includes_dir = "/var/lib/snappy/apparmor"
-
 # The Ubuntu tranformation function takes a click manifest json
 # structure as input and returns an aa-easyprof json manifest
 defaults_profile = {
